# database.py
from sqlalchemy import create_engine, Column, Integer, String, DateTime
from sqlalchemy.orm import declarative_base, sessionmaker
import datetime

Base = declarative_base()
engine = create_engine('sqlite:///bot.db')
Session = sessionmaker(bind=engine)

class Warning(Base):
    __tablename__ = 'warnings'
    id = Column(Integer, primary_key=True)
    user_id = Column(Integer)
    group_id = Column(Integer)
    reason = Column(String)
    timestamp = Column(DateTime, default=datetime.datetime.utcnow)

class Rule(Base):
    __tablename__ = 'rules'
    id = Column(Integer, primary_key=True)
    group_id = Column(Integer)
    text = Column(String)

class Birthday(Base):
    __tablename__ = 'birthdays'
    id = Column(Integer, primary_key=True)
    user_id = Column(Integer)
    group_id = Column(Integer)
    date = Column(String)

class Invite(Base):
    __tablename__ = 'invites'
    id = Column(Integer, primary_key=True)
    user_id = Column(Integer)
    invited_by = Column(Integer)
    group_id = Column(Integer)

class ScheduledMessage(Base):
    __tablename__ = 'scheduled_messages'
    id = Column(Integer, primary_key=True)
    group_id = Column(Integer)
    text = Column(String)
    time = Column(String)  # e.g., "14:00"

class UserData(Base):
    __tablename__ = 'user_data'
    id = Column(Integer, primary_key=True)
    user_id = Column(Integer, unique=True)
    mobile_number = Column(String, nullable=True)

Base.metadata.create_all(engine)
